/*
 * radio_hal_interface.h
 *
 * Copyright (c) 2000 - 2016 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

#ifdef __cplusplus
extern "C" {
#endif

#include <stdint.h>
#include <stdio.h>
#include <stdlib.h>
#include "tizen-radio.h"

typedef enum _seek_direction_type {
	SEEK_DIRECTION_UP,	/**< Seek upward */
	SEEK_DIRECTION_DOWN	/**< Seek downward */
} seek_direction_type_t;

typedef struct _radio_hal_interface {
	void *dl_handle;
	void *rh_handle;
	radio_interface_t intf;
} radio_hal_interface;

int radio_hal_interface_init(radio_hal_interface **handle);
int radio_hal_interface_deinit(radio_hal_interface *handle);
int radio_hal_open(radio_hal_interface *handle);
int radio_hal_prepare(radio_hal_interface *handle);
int radio_hal_unprepare(radio_hal_interface *handle);
int radio_hal_close(radio_hal_interface *handle);
int radio_hal_start(radio_hal_interface *handle);
int radio_hal_stop(radio_hal_interface *handle);
int radio_hal_seek(radio_hal_interface *handle, seek_direction_type_t direction);
int radio_hal_get_frequency(radio_hal_interface *handle, uint32_t *frequency);
int radio_hal_set_frequency(radio_hal_interface *handle, uint32_t frequency);
int radio_hal_get_signal_strength(radio_hal_interface *handle, int32_t *strength);
int radio_hal_mute(radio_hal_interface *handle);
int radio_hal_unmute(radio_hal_interface *handle);
int radio_hal_set_volume(radio_hal_interface *handle, float volume);
int radio_hal_get_volume(radio_hal_interface *handle, float *volume);
int radio_hal_set_media_volume(radio_hal_interface *handle, uint32_t level);


#ifdef __cplusplus
}
#endif
